WasmHash

Struct WasmHash 

pub struct WasmHash(/* private fields */);
The hash of a wasm module.

Used as a key when loading and storing modules in a Cache.

Implementations

Source

impl WasmHash

pub fn generate(wasm: &[u8]) -> WasmHash

Hash a wasm module.

Note:

This does no verification that the supplied data is, in fact, a wasm module.

pub fn encode(self) -> String

Create the hexadecimal representation of the stored hash.

pub fn decode(hex_str: &str) -> Result<WasmHash, Error>

Create hash from hexadecimal representation