Backend

Enum Backend 

pub enum Backend {
    Auto,
}
Enum used to select which compiler should be used to generate code.

Variants



Auto

Auto backend

Implementations

Source

impl Backend

pub fn variants() -> &'static [&'static str]

Get a list of the currently enabled (via feature flag) backends.

pub fn to_string(&self) -> &'static str

Stable string representation of the backend. It can be used as part of a cache key, for example.