pub struct CodeVersion {
pub baseline: bool,
pub msm: ModuleStateMap,
pub base: usize,
pub backend: &'static str,
pub runnable_module: Arc<Box<dyn RunnableModule>>,
}Expand description
A CodeVersion is a container for a unit of generated code for a module.
Fields
baseline: boolIndicates if this code version is the baseline version.
msm: ModuleStateMapModuleStateMap for this code version.
base: usizeA pointer to the machine code for this module.
backend: &'static strThe backend used to compile this module.
runnable_module: Arc<Box<dyn RunnableModule>>RunnableModule for this code version.