pub struct StreamingCompiler<MCG, FCG, RM, E, CGEN>where
MCG: ModuleCodeGenerator<FCG, RM, E>,
FCG: FunctionCodeGenerator<E>,
RM: RunnableModule + 'static,
E: Debug,
CGEN: Fn() -> MiddlewareChain,{ /* private fields */ }Expand description
A streaming compiler which is designed to generated code for a module based on a stream of wasm parser events.
Implementations
Sourceimpl<MCG, FCG, RM, E, CGEN> StreamingCompiler<MCG, FCG, RM, E, CGEN>where
MCG: ModuleCodeGenerator<FCG, RM, E>,
FCG: FunctionCodeGenerator<E>,
RM: RunnableModule + 'static,
E: Debug,
CGEN: Fn() -> MiddlewareChain,
impl<MCG, FCG, RM, E, CGEN> StreamingCompiler<MCG, FCG, RM, E, CGEN>where
MCG: ModuleCodeGenerator<FCG, RM, E>,
FCG: FunctionCodeGenerator<E>,
RM: RunnableModule + 'static,
E: Debug,
CGEN: Fn() -> MiddlewareChain,
Sourcepub fn new(chain_gen: CGEN) -> StreamingCompiler<MCG, FCG, RM, E, CGEN>
pub fn new(chain_gen: CGEN) -> StreamingCompiler<MCG, FCG, RM, E, CGEN>
Create a new StreamingCompiler with the given MiddlewareChain.