pub struct FuncSig { /* private fields */ }Expand description
The signature of a function that is either implemented in a wasm module or exposed to wasm by the host.
Implementations
Sourceimpl FuncSig
impl FuncSig