TableDescriptor

Struct TableDescriptor 

pub struct TableDescriptor {
    pub element: ElementType,
    pub minimum: u32,
    pub maximum: Option<u32>,
}
Describes the properties of a table including the element types, minimum and optional maximum, number of elements in the table.

Fields

element: ElementType

Type of data stored in this table.

minimum: u32

The minimum number of elements that must be stored in this table.

maximum: Option<u32>

The maximum number of elements in this table.